@@ -6,7 +6,7 @@ import csv
 
 import pynmrstar
 
-from pybmrb import ChemicalShift
+from pybmrb import ChemicalShift, ChemicalShiftStatistics
 import plotly.express as px
 from typing import Union, List
 
@@ -15,7 +15,7 @@ def create_c13hsqc_peaklist(bmrb_ids: Union[str, List[str]],
                             entry_objects: Union[pynmrstar.Entry, List[pynmrstar.Entry]] = None,
                             input_file_names: Union[str, List[str]] = None,
                             auth_tag: bool = False,
-                            draw_trace: bool = False):
+                            draw_trace: bool = False) -> tuple:
     """
     Converts one dimensional chemical shifts from list of BMRB entries into CHSQC peak list
 
@@ -107,7 +107,7 @@ def create_tocsy_peaklist(bmrb_ids: Union[str, List[str]],
                           entry_objects: Union[pynmrstar.Entry, List[pynmrstar.Entry]] = None,
                           input_file_names: Union[str, List[str]] = None,
                           auth_tag: bool = False,
-                          draw_trace: bool = False):
+                          draw_trace: bool = False) -> tuple:
     """
     Converts one dimensional chemical shifts from list of BMRB entries into TOCSY peak list
 
@@ -175,7 +175,10 @@ def create_2d_peaklist(bmrb_ids: Union[str, List[str]],
                        atom_x: str, atom_y: str, input_file_names: Union[str, List[str]] = None,
                        entry_objects: Union[pynmrstar.Entry, List[pynmrstar.Entry]] = None,
                        auth_tag: bool = False,
-                       draw_trace: bool = False):
+                       draw_trace: bool = False,
+                       include_preceding: bool = False,
+                       include_next: bool = False,
+                       legend: str = None) -> tuple:
     """
      Converts one dimensional chemical shifts from list of BMRB entries into generic 2D peak list
 
@@ -186,6 +189,9 @@ def create_2d_peaklist(bmrb_ids: Union[str, List[str]],
     :param entry_objects: One of more PyNMRSTAR entry objects
     :param auth_tag: Use author provided sequence numbering from BMRB/NMR-STAR file; default: False
     :param draw_trace: Connect the matching residues using sequence numbering; default: False
+    :param include_preceding:  include preceding residue chemical shifts
+    :param include_next:  include next residue chemical shifts
+    :param legend:  selection of legend to display
     :return: tuple of lists and dictionary (x,y,data_set,info,res,cs_track);
         cs_track is a dictionary { matching atoms:[cs_values]}
     """
@@ -204,7 +210,9 @@ def create_2d_peaklist(bmrb_ids: Union[str, List[str]],
     y = []
     res = []
     info = []
+    psn = []
     atom_ids = {}
+    seq_trace = [[], [], []]
     for data_id in cs_data.keys():
         for chain in cs_data[data_id].keys():
             for seq_no in cs_data[data_id][chain]['seq_ids']:
@@ -220,11 +228,47 @@ def create_2d_peaklist(bmrb_ids: Union[str, List[str]],
                                 if ('*' in ch_atom[1]
                                     and ch_atom[1][:-1] == atm_y[:len(ch_atom[1][:-1])]) \
                                         or (ch_atom[1] == atm_y):
+                                    if include_preceding:
+                                        try:
+                                            residue_p = cs_data[data_id][chain][seq_no - 1][
+                                                list(cs_data[data_id][chain][seq_no - 1].keys())[0]][0]
+                                            cs_y = cs_data[data_id][chain][seq_no - 1][atm_y][2]
+                                            data_set.append(data_id)
+                                            x.append(cs_x)
+                                            y.append(cs_y)
+                                            seq_trace[0].append(cs_x)
+                                            seq_trace[1].append(cs_y)
+                                            seq_trace[2].append(seq_no - 1)
+                                            res.append(residue)
+                                            if legend == 'psn':
+                                                psn.append('Preceding')
+                                            else:
+                                                psn.append(0.5)
+                                            tag = '{}-{}-{}-{}-{}-{}-{}-{}'.format(data_id, chain, seq_no, residue,
+                                                                                   seq_no - 1, residue_p, atm_x,
+                                                                                   atm_y)
+                                            info.append(tag)
+                                            atom_id = '{}-{}-{}-{}-{}-{}-{}'.format(chain, seq_no, residue, seq_no - 1,
+                                                                                    residue_p, atm_x, atm_y)
+                                            if draw_trace:
+                                                if atom_id not in atom_ids.keys():
+                                                    atom_ids[atom_id] = [[], []]
+                                                atom_ids[atom_id][0].append(cs_x)
+                                                atom_ids[atom_id][1].append(cs_y)
+                                        except KeyError:
+                                            pass
                                     cs_y = cs_data[data_id][chain][seq_no][atm_y][2]
                                     data_set.append(data_id)
                                     x.append(cs_x)
                                     y.append(cs_y)
+                                    seq_trace[0].append(cs_x)
+                                    seq_trace[1].append(cs_y)
+                                    seq_trace[2].append(seq_no)
                                     res.append(residue)
+                                    if legend == 'psn':
+                                        psn.append('Same')
+                                    else:
+                                        psn.append(1)
                                     tag = '{}-{}-{}-{}-{}-{}'.format(data_id, chain, seq_no, residue, atm_x, atm_y)
                                     info.append(tag)
                                     atom_id = '{}-{}-{}-{}-{}'.format(chain, seq_no, residue, atm_x, atm_y)
@@ -233,12 +277,42 @@ def create_2d_peaklist(bmrb_ids: Union[str, List[str]],
                                             atom_ids[atom_id] = [[], []]
                                         atom_ids[atom_id][0].append(cs_x)
                                         atom_ids[atom_id][1].append(cs_y)
+                                    if include_next:
+                                        try:
+                                            residue_p = cs_data[data_id][chain][seq_no + 1][
+                                                list(cs_data[data_id][chain][seq_no + 1].keys())[0]][0]
+                                            cs_y = cs_data[data_id][chain][seq_no + 1][atm_y][2]
+                                            data_set.append(data_id)
+                                            x.append(cs_x)
+                                            y.append(cs_y)
+                                            seq_trace[0].append(cs_x)
+                                            seq_trace[1].append(cs_y)
+                                            seq_trace[2].append(seq_no + 1)
+                                            res.append(residue)
+                                            if legend == 'psn':
+                                                psn.append('Next')
+                                            else:
+                                                psn.append(0.5)
+                                            tag = '{}-{}-{}-{}-{}-{}-{}-{}'.format(data_id, chain, seq_no, residue,
+                                                                                   seq_no + 1, residue_p, atm_x,
+                                                                                   atm_y)
+                                            info.append(tag)
+                                            atom_id = '{}-{}-{}-{}-{}-{}-{}'.format(chain, seq_no, residue, seq_no + 1,
+                                                                                    residue_p, atm_x, atm_y)
+                                            if draw_trace:
+                                                if atom_id not in atom_ids.keys():
+                                                    atom_ids[atom_id] = [[], []]
+                                                atom_ids[atom_id][0].append(cs_x)
+                                                atom_ids[atom_id][1].append(cs_y)
+                                        except KeyError:
+                                            pass
+
     cs_track = {}
     if draw_trace:
         for k in atom_ids.keys():
             if len(atom_ids[k][0]) > 1:
                 cs_track[k] = atom_ids[k]
-    return x, y, data_set, info, res, cs_track
+    return x, y, data_set, info, res, cs_track, psn, seq_trace
 
 
 def create_n15hsqc_peaklist(bmrb_ids: Union[str, List[str]],
@@ -246,7 +320,7 @@ def create_n15hsqc_peaklist(bmrb_ids: Union[str, List[str]],
                             entry_objects: Union[pynmrstar.Entry, List[pynmrstar.Entry]] = None,
                             auth_tag: bool = False,
                             draw_trace: bool = False,
-                            include_sidechain: bool = True):
+                            include_sidechain: bool = True) -> tuple:
     """
     Converts one dimensional chemical shifts from list of BMRB entries into NHSQC peak list
 
@@ -310,7 +384,7 @@ def create_n15hsqc_peaklist(bmrb_ids: Union[str, List[str]],
                     y_cs = cs_data[data_id][chain][seq_no][atom_y][2]
                     residue = cs_data[data_id][chain][seq_no][atom_y][0]
                     res.append(residue)
-                    tag = '{}-{}-{}-{}'.format(data_id, chain, seq_no, residue)
+                    tag = '{}-{}-{}-{}-H-N'.format(data_id, chain, seq_no, residue)
                     data_set.append(data_id)
                     atom_id = '{}-{}-{}'.format(chain, seq_no, residue)
                     if draw_trace:
@@ -367,7 +441,7 @@ def n15hsqc(bmrb_ids: Union[str, List[str]] = None,
             output_file: str = None,
             output_image_width: int = 800,
             output_image_height: int = 600,
-            show_visualization: bool = True):
+            show_visualization: bool = True) -> tuple:
     """
     Plots NHSQC spectrum  for a given list of BMRB IDs (or) local NMR-STAR files (or) both
 
@@ -528,7 +602,7 @@ def c13hsqc(bmrb_ids: Union[str, List[str]],
             output_file: str = None,
             output_image_width: int = 800,
             output_image_height: int = 600,
-            show_visualization: bool = True):
+            show_visualization: bool = True) -> tuple:
     """
     Plots CHSQC spectrum  for a given list of BMRB IDs (or) local NMR-STAR files (or) both
 
@@ -681,7 +755,7 @@ def tocsy(bmrb_ids: Union[str, List[str]],
           output_file: str = None,
           output_image_width: int = 800,
           output_image_height: int = 600,
-          show_visualization: bool = True):
+          show_visualization: bool = True) -> tuple:
     """
     Plots TOCSY spectrum  for a given list of BMRB IDs (or) local NMR-STAR files (or) both
 
@@ -830,11 +904,15 @@ def generic_2d(bmrb_ids: Union[str, List[str]],
                legend: str = None,
                draw_trace: bool = False,
                peak_list: str = None,
+               include_preceding: bool = False,
+               include_next: bool = False,
+               full_walk: bool = False,
+               seq_walk: bool = False,
                output_format: str = None,
                output_file: str = None,
                output_image_width: int = 800,
                output_image_height: int = 600,
-               show_visualization: bool = True):
+               show_visualization: bool = True) -> tuple:
     """
     Plots generic 2D spectrum  for a given list of BMRB IDs (or) local NMR-STAR files (or) both
 
@@ -846,6 +924,10 @@ def generic_2d(bmrb_ids: Union[str, List[str]],
     :param auth_tag: use author provided sequence numbering from BMRB /NMR-STAR file; default: False
     :param legend: legend based on residue name or data set id; values: None, residue, datase ; default None
     :param draw_trace: Connect matching residues by list
+    :param include_preceding: include i-1 residue on y axis
+    :param include_next: include i+i residue on y axix
+    :param seq_walk: draw trace to connect i-> i+i  and so one.
+    :param full_walk: draw trace ignoring missing resonances
     :param peak_list: optionally peak list as csv file cam be provided
     :param output_format: html,jpg,png,pdf,wabp,None; default None opens figure in default web browser
     :param output_file: output file name default None
@@ -860,7 +942,10 @@ def generic_2d(bmrb_ids: Union[str, List[str]],
                                       input_file_names=input_file_names,
                                       entry_objects=entry_objects,
                                       auth_tag=auth_tag,
-                                      draw_trace=draw_trace)
+                                      draw_trace=draw_trace,
+                                      include_preceding=include_preceding,
+                                      include_next=include_next,
+                                      legend=legend)
     x1 = []
     y1 = []
     if peak_list is not None:
@@ -875,6 +960,32 @@ def generic_2d(bmrb_ids: Union[str, List[str]],
     info = peak_list_2d[3]
     res = peak_list_2d[4]
     cs_track = peak_list_2d[5]
+    psn = peak_list_2d[6]
+    seq_trace = peak_list_2d[7]
+
+    def sequence_walk(seq_t, filt=True):
+        seq_traces = {}
+        j = 0
+        s = -999
+        for i in range(len(seq_t[0])):
+            if seq_t[2][i] == s or seq_t[2][i] == s + 1:
+                s = seq_t[2][i]
+                seq_traces['walk_{}'.format(j)][0].append(seq_t[0][i])
+                seq_traces['walk_{}'.format(j)][1].append(seq_t[1][i])
+            else:
+                s = seq_t[2][i]
+                j += 1
+                seq_traces['walk_{}'.format(j)] = [[seq_t[0][i]], [seq_t[1][i]]]
+        sq_w = {}
+        if filt:
+            for k1 in seq_traces.keys():
+                if len(seq_traces[k1][0]) > 1:
+                    sq_w[k1] = seq_traces[k1]
+        else:
+            sq_w = seq_traces
+        return sq_w
+
+    sq_walk = sequence_walk(seq_trace)
     if len(x) == 0 or len(y) == 0:
         logging.error('Required chemical shifts not found')
         raise ValueError('Required chemical shifts not found')
@@ -883,12 +994,18 @@ def generic_2d(bmrb_ids: Union[str, List[str]],
                          title='Simulated {}-{} COSY peak positions'.format(atom_x, atom_y),
                          symbol=data_set,
                          hover_name=info,
+                         size=psn,
                          color=res,
                          labels={"color": "Residue",
                                  "symbol": "Data set",
                                  "x": '{} (ppm)'.format(atom_x),
-                                 "y": '{} (ppm)'.format(atom_y)}, opacity=0.7).update(
-            layout=dict(title=dict(x=0.5)))
+                                 "y": '{} (ppm)'.format(atom_y)}, opacity=0.7)
+        fig.update(layout=dict(title=dict(x=0.5)))
+        if full_walk:
+            fig.add_scatter(x=seq_trace[0], y=seq_trace[1], name='Full walk', opacity=0.7, mode='lines')
+        if seq_walk:
+            for k in sq_walk.keys():
+                fig.add_scatter(x=sq_walk[k][0], y=sq_walk[k][1], name=k, opacity=0.7, mode='lines')
         if draw_trace:
             for k in cs_track.keys():
                 fig.add_scatter(x=cs_track[k][0], y=cs_track[k][1], name=k, opacity=0.7, mode='lines')
@@ -903,11 +1020,17 @@ def generic_2d(bmrb_ids: Union[str, List[str]],
                          title='Simulated {}-{} COSY peak positions'.format(atom_x, atom_y),
                          hover_name=info,
                          color=res,
+                         size=psn,
                          labels={"color": "Residue",
                                  # "symbol": "Data set",
                                  "x": '{} (ppm)'.format(atom_x),
                                  "y": '{} (ppm)'.format(atom_y)}, opacity=0.7).update(
             layout=dict(title=dict(x=0.5)))
+        if full_walk:
+            fig.add_scatter(x=seq_trace[0], y=seq_trace[1], name='Full walk', opacity=0.7, mode='lines')
+        if seq_walk:
+            for k in sq_walk.keys():
+                fig.add_scatter(x=sq_walk[k][0], y=sq_walk[k][1], name=k, opacity=0.7, mode='lines')
         if draw_trace:
             for k in cs_track.keys():
                 fig.add_scatter(x=cs_track[k][0], y=cs_track[k][1], name=k, opacity=0.7, mode='lines')
@@ -921,11 +1044,39 @@ def generic_2d(bmrb_ids: Union[str, List[str]],
                          title='Simulated {}-{} COSY peak positions'.format(atom_x, atom_y),
                          hover_name=info,
                          color=data_set,
+                         size=psn,
                          labels={"color": "Data set",
                                  # "symbol": "Data set",
                                  "x": '{} (ppm)'.format(atom_x),
                                  "y": '{} (ppm)'.format(atom_y)}, opacity=0.7).update(
             layout=dict(title=dict(x=0.5)))
+        if full_walk:
+            fig.add_scatter(x=seq_trace[0], y=seq_trace[1], name='Full walk', opacity=0.7, mode='lines')
+        if seq_walk:
+            for k in sq_walk.keys():
+                fig.add_scatter(x=sq_walk[k][0], y=sq_walk[k][1], name=k, opacity=0.7, mode='lines')
+        if draw_trace:
+            for k in cs_track.keys():
+                fig.add_scatter(x=cs_track[k][0], y=cs_track[k][1], name=k, opacity=0.7, mode='lines')
+        if peak_list is not None:
+            fig.add_scatter(x=x1, y=y1, mode='markers', name='Peak list', opacity=0.7)
+        fig.update_xaxes(autorange="reversed")
+        fig.update_yaxes(autorange="reversed")
+    elif legend == 'psn':
+        fig = px.scatter(x=x, y=y,
+                         title='Simulated {}-{} COSY peak positions'.format(atom_x, atom_y),
+                         hover_name=info,
+                         color=psn,
+                         labels={"color": "Data set",
+                                 # "symbol": "Data set",
+                                 "x": '{} (ppm)'.format(atom_x),
+                                 "y": '{} (ppm)'.format(atom_y)}, opacity=0.7).update(
+            layout=dict(title=dict(x=0.5)))
+        if full_walk:
+            fig.add_scatter(x=seq_trace[0], y=seq_trace[1], name='Full walk', opacity=0.7, mode='lines')
+        if seq_walk:
+            for k in sq_walk.keys():
+                fig.add_scatter(x=sq_walk[k][0], y=sq_walk[k][1], name=k, opacity=0.7, mode='lines')
         if draw_trace:
             for k in cs_track.keys():
                 fig.add_scatter(x=cs_track[k][0], y=cs_track[k][1], name=k, opacity=0.7, mode='lines')
@@ -976,10 +1127,130 @@ def generic_2d(bmrb_ids: Union[str, List[str]],
         else:
             logging.error('Output file format not support:{}'.format(output_format))
     return x, y, data_set, info, res, cs_track
+
+
+def export_peak_list(peak_list: tuple, output_format: str = 'csv', include_side_chain: bool = True,
+                     output_file_name: str = None) -> dict:
+    """
+    Exports peak list in csv or sparky format
+
+    :param peak_list: Output tuple from any spectra simulation function from the module Spectra
+    :param output_format: csv or sparky
+    :param include_side_chain: whether or not side chain resonances included in the output; default True
+    :param output_file_name: output file name
+    :return: data dictionary; {'column header1':[values],'column header1':[values]..}
+    """
+    back_bone = ['H', 'N', 'C', 'CA']
+    if output_format == 'csv':
+        csv_dict = {'sequence': [],
+                    'chem_comp_ID': [],
+                    'X_shift': [],
+                    'Y_shift': [],
+                    'X_atom_name': [],
+                    'Y_atom_name': []}
+        for i in range(len(peak_list[0])):
+            atom_x = peak_list[3][i].split("-")[5]
+            atom_y = peak_list[3][i].split("-")[6]
+            if not include_side_chain:
+                if atom_x in back_bone and atom_y in back_bone:
+                    csv_dict['sequence'].append(peak_list[3][i].split("-")[3])
+                    csv_dict['chem_comp_ID'].append(peak_list[3][i].split("-")[4])
+                    csv_dict['X_shift'].append(peak_list[0][i])
+                    csv_dict['Y_shift'].append(peak_list[1][i])
+                    csv_dict['X_atom_name'].append(peak_list[3][i].split("-")[5])
+                    csv_dict['Y_atom_name'].append(peak_list[3][i].split("-")[6])
+
+            else:
+                csv_dict['sequence'].append(peak_list[3][i].split("-")[3])
+                csv_dict['chem_comp_ID'].append(peak_list[3][i].split("-")[4])
+                csv_dict['X_shift'].append(peak_list[0][i])
+                csv_dict['Y_shift'].append(peak_list[1][i])
+                csv_dict['X_atom_name'].append(peak_list[3][i].split("-")[5])
+                csv_dict['Y_atom_name'].append(peak_list[3][i].split("-")[6])
+        if output_file_name is not None:
+            fo = open(output_file_name, 'w')
+            fo.write('sequence,chem_comp_ID,X_shift,Y_shift,X_atom_name,Y_atom_name\n')
+            for i in range(len(csv_dict['sequence'])):
+                fo.write('{},{},{},{},{},{}\n'.format(csv_dict['sequence'][i],
+                                                      csv_dict['chem_comp_ID'][i],
+                                                      round(float(csv_dict['X_shift'][i]), 3),
+                                                      round(float(csv_dict['Y_shift'][i]), 3),
+                                                      csv_dict['X_atom_name'][i],
+                                                      csv_dict['Y_atom_name'][i]))
+            fo.close()
+    elif output_format == 'sparky':
+        csv_dict = {'Assignment': [],
+                    'w1': [],
+                    'w2': []}
+        for i in range(len(peak_list[0])):
+            atom_x = peak_list[3][i].split("-")[5]
+            atom_y = peak_list[3][i].split("-")[6]
+            res = peak_list[3][i].split("-")[4]
+            try:
+                assignment = '{}{}{}-{}'.format(ChemicalShiftStatistics.one_letter_code[res],
+                                                peak_list[3][i].split("-")[3],
+                                                atom_x, atom_y)
+            except KeyError:
+                assignment = '{}{}{}-{}'.format('X',
+                                                peak_list[3][i].split("-")[3],
+                                                atom_x, atom_y)
+            if not include_side_chain:
+                if atom_x in back_bone and atom_y in back_bone:
+                    csv_dict['Assignment'].append(assignment)
+                    csv_dict['w1'].append(peak_list[0][i])
+                    csv_dict['w2'].append(peak_list[1][i])
+            else:
+                csv_dict['Assignment'].append(assignment)
+                csv_dict['w1'].append(peak_list[0][i])
+                csv_dict['w2'].append(peak_list[1][i])
+        if output_file_name is not None:
+            fo = open(output_file_name, 'w')
+            fo.write('Assignment  \t{:>6}\t\t{:>6}\n\n'.format('w1', 'w2'))
+            for i in range(len(csv_dict['Assignment'])):
+                fo.write('{:<10}\t\t{:>6}\t\t{:>6}\n'.format(csv_dict['Assignment'][i],
+                                                             round(float(csv_dict['w1'][i]), 3),
+                                                             round(float(csv_dict['w2'][i]), 3)))
+            fo.close()
+    else:
+        logging.error('Output format not supported')
+        raise ValueError('Output format not supported')
+    return csv_dict
+#
 #
 # if __name__ == "__main__":
-#     p=n15hsqc(bmrb_ids=[17300,17299],draw_trace=True)
-# # Generating examples for documentation
+#     p = generic_2d(bmrb_ids=15000, atom_x='N', atom_y='CA',
+#                    include_preceding=True,legend='residue',output_format='jpg',
+#                    output_file='../docs/_images/n_cb_p.jpg')
+#     p = generic_2d(bmrb_ids=15000, atom_x='N', atom_y='CA',
+#                    include_preceding=True, legend='residue', output_format='html',
+#                    output_file='../docs/_static/n_cb_p.html')
+#     p = generic_2d(bmrb_ids=15000, atom_x='N', atom_y='CA',
+#                    include_next=True, legend='residue', output_format='jpg',
+#                    output_file='../docs/_images/n_cb_n.jpg')
+#     p = generic_2d(bmrb_ids=15000, atom_x='N', atom_y='CA',
+#                    include_next=True, legend='residue', output_format='html',
+#                    output_file='../docs/_static/n_cb_n.html')
+#     p = generic_2d(bmrb_ids=15000, atom_x='N', atom_y='CA',seq_walk=True,
+#                    include_preceding=True, legend='residue', output_format='jpg',
+#                    output_file='../docs/_images/n_cb_p_w.jpg')
+#     p = generic_2d(bmrb_ids=15000, atom_x='N', atom_y='CA',seq_walk=True,
+#                    include_preceding=True, legend='residue', output_format='html',
+#                    output_file='../docs/_static/n_cb_p_w.html')
+#     p = generic_2d(bmrb_ids=15000, atom_x='N', atom_y='CA',seq_walk=True,
+#                    include_next=True, legend='residue', output_format='jpg',
+#                    output_file='../docs/_images/n_cb_n_w.jpg')
+#     p = generic_2d(bmrb_ids=15000, atom_x='N', atom_y='CA',seq_walk=True,
+#                    include_next=True, legend='residue', output_format='html',
+#                    output_file='../docs/_static/n_cb_n_w.html')
+#     p = generic_2d(bmrb_ids=15000, atom_x='N', atom_y='CA', full_walk=True,
+#                    include_next=True, legend='residue', output_format='jpg',
+#                    output_file='../docs/_images/n_cb_n_w_f.jpg')
+#     p = generic_2d(bmrb_ids=15000, atom_x='N', atom_y='CA', full_walk=True,
+#                    include_next=True, legend='residue', output_format='html',
+#                    output_file='../docs/_static/n_cb_n_w_f.html')
+
+#     pk = export_peak_list(p, output_format='csv', output_file_name='test.csv')
+# Generating examples for documentation
 # n15hsqc(bmrb_ids=15060,output_format='jpg',legend='residue',output_file='../docs/_images/15060_n15',
 #                 show_visualization=False)
 # n15hsqc(bmrb_ids=15060, output_format='html', legend='residue',output_file='../docs/_static/15060_n15',
